:mod:`stix.utils.parser` Module
==================================

.. module:: stix.utils.parser

Classes
-------

.. autoclass:: UnsupportedVersionError
	:show-inheritance:
	:members:

.. autoclass:: UnknownVersionError
	:show-inheritance:
	:members:

.. autoclass:: UnsupportedRootElement
	:show-inheritance:
	:members:

.. autoclass:: EntityParser
	:show-inheritance:
	:members:
